@@ -1,26 +1,26 @@
 resolve_size <- function(...) {
   size <- rlang::list2(...)
-  
+
   if (!is.null(size[["size"]])) {
-    
-    if (!length(size) == 1)
+    if (!length(size) == 1) {
       stop("You should specify a single size argument.")
-    
+    }
+
     size <- size[["size"]]
   } else if (length(size[[1]]) > 1) {
-    
-    if (!length(size) == 1)
+    if (!length(size) == 1) {
       stop("You should specify a single size argument.")
-    
+    }
+
     size <- size[[1]]
   }
-  
+
   size
 }
 
 #' @rdname torch_ones
-torch_ones <- function(..., names = NULL, dtype = NULL, layout = torch_strided(), 
-  device=NULL, requires_grad = FALSE) {
+torch_ones <- function(..., names = NULL, dtype = NULL, layout = torch_strided(),
+                       device = NULL, requires_grad = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -35,8 +35,8 @@ torch_ones <- function(..., names = NULL, dtype = NULL, layout = torch_strided()
 }
 
 #' @rdname torch_ones_like
-torch_ones_like <- function(input, dtype = NULL, layout = torch_strided(), 
-                            device=NULL, requires_grad = FALSE, 
+torch_ones_like <- function(input, dtype = NULL, layout = torch_strided(),
+                            device = NULL, requires_grad = FALSE,
                             memory_format = torch_preserve_format()) {
   args <- list(
     options = torch_tensor_options(
@@ -52,8 +52,8 @@ torch_ones_like <- function(input, dtype = NULL, layout = torch_strided(),
 }
 
 #' @rdname torch_rand
-torch_rand <- function(..., names = NULL, dtype = NULL, layout = torch_strided(), 
-                       device=NULL, requires_grad = FALSE) {
+torch_rand <- function(..., names = NULL, dtype = NULL, layout = torch_strided(),
+                       device = NULL, requires_grad = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -68,8 +68,8 @@ torch_rand <- function(..., names = NULL, dtype = NULL, layout = torch_strided()
 }
 
 #' @rdname torch_rand_like
-torch_rand_like <- function(input, dtype = NULL, layout = torch_strided(), 
-                            device=NULL, requires_grad = FALSE, 
+torch_rand_like <- function(input, dtype = NULL, layout = torch_strided(),
+                            device = NULL, requires_grad = FALSE,
                             memory_format = torch_preserve_format()) {
   args <- list(
     options = torch_tensor_options(
@@ -85,10 +85,9 @@ torch_rand_like <- function(input, dtype = NULL, layout = torch_strided(),
 }
 
 #' @rdname torch_randint
-torch_randint <- function(low, high, size, generator = NULL, dtype = NULL, layout = torch_strided(), 
-                          device=NULL, requires_grad = FALSE, 
+torch_randint <- function(low, high, size, generator = NULL, dtype = NULL, layout = torch_strided(),
+                          device = NULL, requires_grad = FALSE,
                           memory_format = torch_preserve_format()) {
-  
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -101,14 +100,14 @@ torch_randint <- function(low, high, size, generator = NULL, dtype = NULL, layou
   args$high <- high
   args$size <- size
   if (!is.null(generator)) args$generator <- NULL
-  
+
   do.call(.torch_randint, args)
 }
 
 #' @rdname torch_randint_like
-torch_randint_like <- function(input, low, high, dtype = NULL, 
-                               layout = torch_strided(), 
-                               device=NULL, requires_grad = FALSE) {
+torch_randint_like <- function(input, low, high, dtype = NULL,
+                               layout = torch_strided(),
+                               device = NULL, requires_grad = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -120,13 +119,13 @@ torch_randint_like <- function(input, low, high, dtype = NULL,
   args$self <- input
   args$low <- low
   args$high <- high
-  
+
   do.call(.torch_randint_like, args)
 }
 
 #' @rdname torch_randn
-torch_randn <- function(..., names = NULL, dtype = NULL, layout = torch_strided(), 
-                       device=NULL, requires_grad = FALSE) {
+torch_randn <- function(..., names = NULL, dtype = NULL, layout = torch_strided(),
+                        device = NULL, requires_grad = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -141,9 +140,9 @@ torch_randn <- function(..., names = NULL, dtype = NULL, layout = torch_strided(
 }
 
 #' @rdname torch_randn_like
-torch_randn_like <- function(input, dtype = NULL, layout = torch_strided(), 
-                            device=NULL, requires_grad = FALSE, 
-                            memory_format = torch_preserve_format()) {
+torch_randn_like <- function(input, dtype = NULL, layout = torch_strided(),
+                             device = NULL, requires_grad = FALSE,
+                             memory_format = torch_preserve_format()) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -158,8 +157,8 @@ torch_randn_like <- function(input, dtype = NULL, layout = torch_strided(),
 }
 
 #' @rdname torch_randperm
-torch_randperm <- function(n, dtype = torch_int64(), layout = torch_strided(), 
-                           device=NULL, requires_grad = FALSE) {
+torch_randperm <- function(n, dtype = torch_int64(), layout = torch_strided(),
+                           device = NULL, requires_grad = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -173,8 +172,8 @@ torch_randperm <- function(n, dtype = torch_int64(), layout = torch_strided(),
 }
 
 #' @rdname torch_zeros
-torch_zeros <- function(..., names = NULL, dtype = NULL, layout = torch_strided(), 
-                       device=NULL, requires_grad = FALSE) {
+torch_zeros <- function(..., names = NULL, dtype = NULL, layout = torch_strided(),
+                        device = NULL, requires_grad = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -189,9 +188,9 @@ torch_zeros <- function(..., names = NULL, dtype = NULL, layout = torch_strided(
 }
 
 #' @rdname torch_zeros_like
-torch_zeros_like <- function(input, dtype = NULL, layout = torch_strided(), 
-                            device=NULL, requires_grad = FALSE, 
-                            memory_format = torch_preserve_format()) {
+torch_zeros_like <- function(input, dtype = NULL, layout = torch_strided(),
+                             device = NULL, requires_grad = FALSE,
+                             memory_format = torch_preserve_format()) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -206,8 +205,8 @@ torch_zeros_like <- function(input, dtype = NULL, layout = torch_strided(),
 }
 
 #' @rdname torch_empty
-torch_empty <- function(..., names = NULL, dtype = NULL, layout = torch_strided(), 
-                        device=NULL, requires_grad = FALSE) {
+torch_empty <- function(..., names = NULL, dtype = NULL, layout = torch_strided(),
+                        device = NULL, requires_grad = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -222,8 +221,8 @@ torch_empty <- function(..., names = NULL, dtype = NULL, layout = torch_strided(
 }
 
 #' @rdname torch_empty_like
-torch_empty_like <- function(input, dtype = NULL, layout = torch_strided(), 
-                             device=NULL, requires_grad = FALSE, 
+torch_empty_like <- function(input, dtype = NULL, layout = torch_strided(),
+                             device = NULL, requires_grad = FALSE,
                              memory_format = torch_preserve_format()) {
   args <- list(
     options = torch_tensor_options(
@@ -239,8 +238,8 @@ torch_empty_like <- function(input, dtype = NULL, layout = torch_strided(),
 }
 
 #' @rdname torch_arange
-torch_arange <- function(start, end, step = 1, dtype = NULL, layout = torch_strided(), 
-                         device=NULL, requires_grad = FALSE) {
+torch_arange <- function(start, end, step = 1, dtype = NULL, layout = torch_strided(),
+                         device = NULL, requires_grad = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -250,27 +249,31 @@ torch_arange <- function(start, end, step = 1, dtype = NULL, layout = torch_stri
     )
   )
   args$start <- start
-  
-  eps <- if (is.null(dtype) || ((!dtype == torch_float32()) && (!dtype == torch_float64())))
-           torch_finfo(torch_get_default_dtype())$eps 
-             else torch_finfo(dtype)$eps
+
+  eps <- if (is.null(dtype) || ((!dtype == torch_float32()) && (!dtype == torch_float64()))) {
+    torch_finfo(torch_get_default_dtype())$eps
+  } else {
+    torch_finfo(dtype)$eps
+  }
   args$end <- end + sign(step) * eps
-  
+
   args$step <- step
   do.call(.torch_arange, args)
 }
 
 #' @rdname torch_range
-torch_range <- function(start, end, step = 1, dtype = NULL, layout = torch_strided(), 
-                        device=NULL, requires_grad = FALSE) {
+torch_range <- function(start, end, step = 1, dtype = NULL, layout = torch_strided(),
+                        device = NULL, requires_grad = FALSE) {
   warning("This function is deprecated in favor of torch_arange.")
-  torch_arange(start = start, end = end, step = step, dtype = dtype, layout = layout, 
-               device=device, requires_grad = requires_grad)
+  torch_arange(
+    start = start, end = end, step = step, dtype = dtype, layout = layout,
+    device = device, requires_grad = requires_grad
+  )
 }
 
 #' @rdname torch_linspace
-torch_linspace <- function(start, end, steps=100, dtype = NULL, layout = torch_strided(), 
-                           device=NULL, requires_grad = FALSE) {
+torch_linspace <- function(start, end, steps = 100, dtype = NULL, layout = torch_strided(),
+                           device = NULL, requires_grad = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -286,8 +289,8 @@ torch_linspace <- function(start, end, steps=100, dtype = NULL, layout = torch_s
 }
 
 #' @rdname torch_logspace
-torch_logspace <- function(start, end, steps=100, base=10, dtype = NULL, layout = torch_strided(), 
-                           device=NULL, requires_grad = FALSE) {
+torch_logspace <- function(start, end, steps = 100, base = 10, dtype = NULL, layout = torch_strided(),
+                           device = NULL, requires_grad = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -304,8 +307,8 @@ torch_logspace <- function(start, end, steps=100, base=10, dtype = NULL, layout
 }
 
 #' @rdname torch_eye
-torch_eye <- function(n, m=n, dtype = NULL, layout = torch_strided(), 
-                      device=NULL, requires_grad = FALSE) {
+torch_eye <- function(n, m = n, dtype = NULL, layout = torch_strided(),
+                      device = NULL, requires_grad = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -320,8 +323,8 @@ torch_eye <- function(n, m=n, dtype = NULL, layout = torch_strided(),
 }
 
 #' @rdname torch_empty_strided
-torch_empty_strided <- function(size, stride, dtype = NULL, layout = torch_strided(), 
-                                device=NULL, requires_grad = FALSE, pin_memory = FALSE) {
+torch_empty_strided <- function(size, stride, dtype = NULL, layout = torch_strided(),
+                                device = NULL, requires_grad = FALSE, pin_memory = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -337,8 +340,8 @@ torch_empty_strided <- function(size, stride, dtype = NULL, layout = torch_strid
 }
 
 #' @rdname torch_full
-torch_full <- function(size, fill_value, names = NULL, dtype = NULL, layout = torch_strided(), 
-                       device=NULL, requires_grad = FALSE) {
+torch_full <- function(size, fill_value, names = NULL, dtype = NULL, layout = torch_strided(),
+                       device = NULL, requires_grad = FALSE) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -354,9 +357,9 @@ torch_full <- function(size, fill_value, names = NULL, dtype = NULL, layout = to
 }
 
 #' @rdname torch_full_like
-torch_full_like <- function(input, fill_value, dtype = NULL, layout = torch_strided(), 
-                             device=NULL, requires_grad = FALSE, 
-                             memory_format = torch_preserve_format()) {
+torch_full_like <- function(input, fill_value, dtype = NULL, layout = torch_strided(),
+                            device = NULL, requires_grad = FALSE,
+                            memory_format = torch_preserve_format()) {
   args <- list(
     options = torch_tensor_options(
       dtype = dtype,
@@ -372,23 +375,25 @@ torch_full_like <- function(input, fill_value, dtype = NULL, layout = torch_stri
 }
 
 #' Scalar tensor
-#' 
+#'
 #' Creates a singleton dimension tensor.
-#' 
+#'
 #' @param value the value you want to use
 #' @inheritParams torch_ones
-#' 
+#'
 #' @export
-torch_scalar_tensor <- function(value, dtype = NULL,  device=NULL, requires_grad = FALSE) {
-  
-  if (is_torch_tensor(value) && !is.null(value$shape) && sum(value$shape) > 1)
+torch_scalar_tensor <- function(value, dtype = NULL, device = NULL, requires_grad = FALSE) {
+  if (is_torch_tensor(value) && !is.null(value$shape) && sum(value$shape) > 1) {
     value_error("values must be lenght 1")
-    
-  if (!is_torch_tensor(value) && length(value) > 1)
-    value_error("value must be a lenght 1 vector")
+  }
 
-  if (is_torch_tensor(value))
+  if (!is_torch_tensor(value) && length(value) > 1) {
+    value_error("value must be a lenght 1 vector")
+  }
+
+  if (is_torch_tensor(value)) {
     value$squeeze()$to(device = device, dtype = dtype)$requires_grad_(requires_grad)
-  else
+  } else {
     torch_tensor(value, dtype = dtype, device = device, requires_grad = requires_grad)$squeeze()
+  }
 }
