@@ -1,7 +1,7 @@
 #' @include nn.R
 NULL
 
-#' Threshoold module
+#' Threshold module
 #'
 #' Thresholds each element of the input Tensor.
 #'
@@ -653,60 +653,68 @@ nn_softshrink <- nn_module(
 
 #' MultiHead attention
 #'
-#' Allows the model to jointly attend to information
-#' from different representation subspaces.
-#' See reference: Attention Is All You Need
+#' Allows the model to jointly attend to information from different
+#' representation subspaces. See reference: Attention Is All You Need
 #'
-#' \deqn{
-#'   \mbox{MultiHead}(Q, K, V) = \mbox{Concat}(head_1,\dots,head_h)W^O
-#' \mbox{where} head_i = \mbox{Attention}(QW_i^Q, KW_i^K, VW_i^V)
-#' }
+#' \deqn{ \mbox{MultiHead}(Q, K, V) = \mbox{Concat}(head_1,\dots,head_h)W^O
+#' \mbox{where} head_i = \mbox{Attention}(QW_i^Q, KW_i^K, VW_i^V) }
 #'
 #' @param embed_dim total dimension of the model.
-#' @param num_heads parallel attention heads.
+#' @param num_heads parallel attention heads. Note that `embed_dim` will be split 
+#'   across `num_heads` (i.e. each head will have dimension `embed_dim %/% num_heads`).
 #' @param dropout a Dropout layer on attn_output_weights. Default: 0.0.
 #' @param bias add bias as module parameter. Default: True.
 #' @param add_bias_kv add bias to the key and value sequences at dim=0.
-#' @param add_zero_attn add a new batch of zeros to the key and
-#'   value sequences at dim=1.
+#' @param add_zero_attn add a new batch of zeros to the key and value sequences
+#'   at dim=1.
 #' @param kdim total number of features in key. Default: `NULL`
-#' @param vdim total number of features in value. Default: `NULL`.
-#'   Note: if kdim and vdim are `NULL`, they will be set to embed_dim such that
-#'   query, key, and value have the same number of features.
+#' @param vdim total number of features in value. Default: `NULL`. Note: if kdim
+#'   and vdim are `NULL`, they will be set to embed_dim such that query, key,
+#'   and value have the same number of features.
+#' @param batch_first if `TRUE` then the input and output tensors are \eqn{(N,
+#'   S, E)} instead of \eqn{(S, N, E)}, where N is the batch size, S is the
+#'   sequence length, and E is the embedding dimension.
 #'
 #' @section Shape:
 #'
-#' Inputs:
+#'   Inputs:
 #'
-#' - query: \eqn{(L, N, E)} where L is the target sequence length, N is the batch size, E is
-#' the embedding dimension.
-#' - key: \eqn{(S, N, E)}, where S is the source sequence length, N is the batch size, E is
-#' the embedding dimension.
-#' - value: \eqn{(S, N, E)} where S is the source sequence length, N is the batch size, E is
-#' the embedding dimension.
-#' - key_padding_mask: \eqn{(N, S)} where N is the batch size, S is the source sequence length.
-#'   If a ByteTensor is provided, the non-zero positions will be ignored while the position
-#'   with the zero positions will be unchanged. If a BoolTensor is provided, the positions with the
-#'   value of ``True`` will be ignored while the position with the value of ``False`` will be unchanged.
-#' - attn_mask: 2D mask \eqn{(L, S)} where L is the target sequence length, S is the source sequence length.
-#'   3D mask \eqn{(N*num_heads, L, S)} where N is the batch size, L is the target sequence length,
-#'   S is the source sequence length. attn_mask ensure that position i is allowed to attend the unmasked
-#'   positions. If a ByteTensor is provided, the non-zero positions are not allowed to attend
-#'   while the zero positions will be unchanged. If a BoolTensor is provided, positions with ``True``
-#'   is not allowed to attend while ``False`` values will be unchanged. If a FloatTensor
-#'   is provided, it will be added to the attention weight.
+#'   - query: \eqn{(L, N, E)} where L is the target sequence length, N is the
+#'   batch size, E is the embedding dimension. (but see the `batch_first` 
+#'   argument)
+#'   - key: \eqn{(S, N, E)}, where S is the source sequence length, N is the 
+#'   batch size, E is the embedding dimension. (but see the `batch_first` 
+#'   argument)
+#'   - value: \eqn{(S, N, E)} where S is the source sequence length,
+#'   N is the batch size, E is the embedding dimension. (but see the 
+#'   `batch_first` argument)
+#'   - key_padding_mask: \eqn{(N, S)} where N is the batch size, S is the source 
+#'   sequence length. If a ByteTensor is provided, the non-zero positions will 
+#'   be ignored while the position with the zero positions will be unchanged. If 
+#'   a BoolTensor is provided, the positions with the value of ``True`` will be 
+#'   ignored while the position with the value of ``False`` will be unchanged. 
+#'   - attn_mask: 2D mask \eqn{(L, S)} where L is the target sequence length, S 
+#'   is the source sequence length. 3D mask \eqn{(N*num_heads, L, S)} where N is 
+#'   the batch size, L is the target sequence length, S is the source sequence 
+#'   length. attn_mask ensure that position i is allowed to attend the unmasked
+#'   positions. If a ByteTensor is provided, the non-zero positions are not
+#'   allowed to attend while the zero positions will be unchanged. If a
+#'   BoolTensor is provided, positions with ``True`` are not allowed to attend
+#'   while ``False`` values will be unchanged. If a FloatTensor is provided, it
+#'   will be added to the attention weight.
 #'
-#' Outputs:
+#'   Outputs:
 #'
-#' - attn_output: \eqn{(L, N, E)} where L is the target sequence length, N is
-#'   the batch size, E is the embedding dimension.
-#' - attn_output_weights:
-#'   - if ``avg_weights`` is ``TRUE`` (the default), the output attention
-#'     weights are averaged over the attention heads, giving a tensor of shape
-#'     \eqn{(N, L, S)} where N is the batch size, L is the target sequence
-#'     length, S is the source sequence length.
-#'   - if ``avg_weights`` is ``FALSE``, the attention weight tensor is output
-#'     as-is, with shape \eqn{(N, H, L, S)}, where H is the number of attention
+#'   - attn_output: \eqn{(L, N, E)} where L is the target sequence length, N is
+#'   the batch size, E is the embedding dimension. (but see the  `batch_first` 
+#'   argument) 
+#'   - attn_output_weights: 
+#'     - if ``avg_weights`` is ``TRUE`` (the default), the output attention 
+#'     weights are averaged over the attention heads, giving a tensor of shape 
+#'     \eqn{(N, L, S)} where N is the batch size, L is the target sequence 
+#'     length, S is the source sequence length. 
+#'     - if ``avg_weights`` is ``FALSE``, the attention weight tensor is output 
+#'     as-is, with shape \eqn{(N, H, L, S)}, where H is the number of attention 
 #'     heads.
 #'
 #' @examples
@@ -720,8 +728,9 @@ nn_softshrink <- nn_module(
 #' @export
 nn_multihead_attention <- nn_module(
   "nn_multihead_attention",
-  initialize = function(embed_dim, num_heads, dropout = 0., bias = TRUE, add_bias_kv = FALSE,
-                        add_zero_attn = FALSE, kdim = NULL, vdim = NULL) {
+  initialize = function(embed_dim, num_heads, dropout = 0., bias = TRUE, 
+                        add_bias_kv = FALSE, add_zero_attn = FALSE, kdim = NULL, 
+                        vdim = NULL, batch_first = FALSE) {
     self$embed_dim <- embed_dim
 
     if (!is.null(kdim)) {
@@ -741,6 +750,10 @@ nn_multihead_attention <- nn_module(
     self$num_heads <- num_heads
     self$dropout <- dropout
     self$head_dim <- embed_dim %/% num_heads
+    
+    if ((self$head_dim * num_heads) != self$embed_dim) {
+      value_error("embed_dim must be divisible by num_heads")
+    }
 
     if (!self$qkv_same_embed_dim_) {
       self$q_proj_weight <- nn_parameter(torch_empty(embed_dim, embed_dim))
@@ -771,6 +784,8 @@ nn_multihead_attention <- nn_module(
     }
 
     self$add_zero_attn <- add_zero_attn
+    
+    self$batch_first <- batch_first
 
     self$reset_parameters()
   },
@@ -808,7 +823,8 @@ nn_multihead_attention <- nn_module(
         key_padding_mask = key_padding_mask, need_weights = need_weights,
         attn_mask = attn_mask, use_separate_proj_weight = TRUE,
         q_proj_weight = self$q_proj_weight, k_proj_weight = self$k_proj_weight,
-        v_proj_weight = self$v_proj_weight
+        v_proj_weight = self$v_proj_weight,
+        batch_first = self$batch_first
       )
     } else {
       nnf_multi_head_attention_forward(
@@ -818,7 +834,8 @@ nn_multihead_attention <- nn_module(
         self$dropout, self$out_proj$weight, self$out_proj$bias,
         training = self$training,
         key_padding_mask = key_padding_mask, need_weights = need_weights,
-        attn_mask = attn_mask, avg_weights = avg_weights
+        attn_mask = attn_mask, avg_weights = avg_weights,
+        batch_first = self$batch_first
       )
     }
   }
