@@ -1,19 +1,21 @@
 list_with_default <- function(out_size, defaults) {
-  
-  if (is.numeric(out_size) && length(out_size) == 1)
+  if (is.numeric(out_size) && length(out_size) == 1) {
     return(out_size)
-  
-  if (length(defaults) >= length(out_size))
+  }
+
+  if (length(defaults) >= length(out_size)) {
     value_error("Input dimension should be at least {lenght(out_size) + 1}.")
-  
+  }
+
   defaults <- utils::tail(defaults, length(out_size))
-    
+
   sapply(
     seq_along(out_size),
     function(i) {
       o <- out_size[[i]]
-      if (is.null(o))
+      if (is.null(o)) {
         o <- defaults[[i]]
+      }
       return(o)
     }
   )
@@ -21,10 +23,10 @@ list_with_default <- function(out_size, defaults) {
 
 nn_util_ntuple <- function(n) {
   function(x) {
-    
-    if (length(x) > 1)
+    if (length(x) > 1) {
       return(x)
-    
+    }
+
     rep(x, n)
   }
 }
