@@ -5,31 +5,31 @@ test_that("sampler's lenght", {
   y <- torch_randn(1000)
   data <- tensor_dataset(x, y)
 
-  sampler <- SequentialSampler$new(data)
+  sampler <- SequentialSampler(data)
   expect_length(sampler, 1000)
 
-  sampler <- RandomSampler$new(data, num_samples = 10)
+  sampler <- RandomSampler(data, num_samples = 10)
   expect_length(sampler, 10)
 
-  sampler <- RandomSampler$new(data)
+  sampler <- RandomSampler(data)
   expect_length(sampler, 1000)
 
-  batch <- BatchSampler$new(sampler = sampler, batch_size = 32, drop_last = TRUE)
+  batch <- BatchSampler(sampler = sampler, batch_size = 32, drop_last = TRUE)
   expect_length(batch, 1000 %/% 32)
 
-  batch <- BatchSampler$new(sampler = sampler, batch_size = 32, drop_last = FALSE)
+  batch <- BatchSampler(sampler = sampler, batch_size = 32, drop_last = FALSE)
   expect_length(batch, 1000 %/% 32 + 1)
 
-  batch <- BatchSampler$new(sampler = sampler, batch_size = 100, drop_last = FALSE)
+  batch <- BatchSampler(sampler = sampler, batch_size = 100, drop_last = FALSE)
   expect_length(batch, 10)
 
-  batch <- BatchSampler$new(sampler = sampler, batch_size = 1000, drop_last = FALSE)
+  batch <- BatchSampler(sampler = sampler, batch_size = 1000, drop_last = FALSE)
   expect_length(batch, 1)
 
-  batch <- BatchSampler$new(sampler = sampler, batch_size = 1001, drop_last = FALSE)
+  batch <- BatchSampler(sampler = sampler, batch_size = 1001, drop_last = FALSE)
   expect_length(batch, 1)
 
-  batch <- BatchSampler$new(sampler = sampler, batch_size = 1001, drop_last = TRUE)
+  batch <- BatchSampler(sampler = sampler, batch_size = 1001, drop_last = TRUE)
   expect_length(batch, 0)
 })
 
@@ -38,7 +38,7 @@ test_that("Random sampler, replacement = TRUE", {
   y <- torch_randn(2)
   data <- tensor_dataset(x, y)
 
-  x <- RandomSampler$new(data, replacement = TRUE)
+  x <- RandomSampler(data, replacement = TRUE)
   it <- x$.iter()
 
   for (i in 1:length(x)) {
@@ -54,8 +54,8 @@ test_that("Batch sampler", {
   y <- torch_randn(2)
   data <- tensor_dataset(x, y)
 
-  r <- RandomSampler$new(data, replacement = FALSE)
-  x <- BatchSampler$new(r, 32, TRUE)
+  r <- RandomSampler(data, replacement = FALSE)
+  x <- BatchSampler(r, 32, TRUE)
   it <- x$.iter()
 
   expect_length(it(), 32)
